@@ -90,7 +90,7 @@ def _processor_startup_fn(pull_port, push_port, sockets_connected_evt, process_f
 
         metadata = message['metadata']
         pixels = deserialize_array(message['pixels'])
-        image = np.reshape(pixels, [metadata['Width'], metadata['Height']])
+        image = np.reshape(pixels, [metadata['Height'], metadata['Width']])
 
         params = signature(process_fn).parameters
         if len(params) == 2 or len(params) == 4:
@@ -119,7 +119,8 @@ def _processor_startup_fn(pull_port, push_port, sockets_connected_evt, process_f
 
 class Acquisition(object):
     def __init__(self, directory=None, name=None, image_process_fn=None,
-                 pre_hardware_hook_fn=None, post_hardware_hook_fn=None, show_display=True, tile_overlap=None,
+                 pre_hardware_hook_fn=None, post_hardware_hook_fn=None, post_camera_hook_fn=None,
+                 show_display=True, tile_overlap=None, max_multi_res_index=None,
                  magellan_acq_index=None, process=True, debug=False):
         """
         :param directory: saving directory for this acquisition. Required unless an image process function will be
@@ -141,14 +142,22 @@ class Acquisition(object):
         :param post_hardware_hook_fn: hook function that will be run just before the hardware is updated before acquiring
             a new image. Accepts either one argument (the current acquisition event) or three arguments (current event,
             bridge, event Queue)
+        :param post_camera_hook_fn: hook function that will be run just after the camera has been triggered to snapImage or
+            startSequence. A common use case for this hook is when one want to send TTL triggers to the camera from an
+            external timing device that synchronizes with other hardware. Accepts either one argument (the current
+            acquisition event) or three arguments (current event, bridge, event Queue)
         :param tile_overlap: If given, XY tiles will be laid out in a grid and multi-resolution saving will be
             actived. Argument can be a two element tuple describing the pixel overlaps between adjacent
             tiles. i.e. (pixel_overlap_x, pixel_overlap_y), or an integer to use the same overlap for both.
             For these features to work, the current hardware configuration must have a valid affine transform
             between camera coordinates and XY stage coordinates
+        :type tile_overlap: tuple, int
+        :param max_multi_res_index: Maximum index to downsample to in multi-res pyramid mode. 0 is no downsampling,
+            1 is downsampled up to 2x, 2 is downsampled up to 4x, etc. If not provided, it will be dynamically
+            calculated and updated from data
+        :type max_multi_res_index: int
         :param show_display: show the image viewer window
         :type show_display: boolean
-        :type tile_overlap: tuple, int
         :param magellan_acq_index: run this acquisition using the settings specified at this position in the main
             GUI of micro-magellan (micro-manager plugin). This index starts at 0
         :type magellan_acq_index: int
@@ -190,8 +199,9 @@ class Acquisition(object):
                     x_overlap = tile_overlap
                     y_overlap = tile_overlap
 
-            self._remote_acq = acq_factory.create_acquisition(directory, name, show_viewer,
-                                                              tile_overlap is not None, x_overlap, y_overlap)
+            self._remote_acq = acq_factory.create_acquisition(directory, name, show_viewer, tile_overlap is not None,
+                                                              x_overlap, y_overlap,
+                                                              max_multi_res_index if max_multi_res_index is not None else -1)
 
         if image_process_fn is not None:
             processor = self.bridge.construct_java_object('org.micromanager.remote.RemoteImageProcessor')
@@ -199,13 +209,18 @@ class Acquisition(object):
             self._start_processor(processor, image_process_fn, self._event_queue, process=process)
 
         if pre_hardware_hook_fn is not None:
-            hook = self.bridge.construct_java_object('org.micromanager.remote.RemoteAcqHook')
+            hook = self.bridge.construct_java_object('org.micromanager.remote.RemoteAcqHook', args=[self._remote_acq])
             self._start_hook(hook, pre_hardware_hook_fn, self._event_queue, process=process)
-            self._remote_acq.add_hook(hook, self._remote_acq.BEFORE_HARDWARE_HOOK, args=[self._remote_acq])
+            self._remote_acq.add_hook(hook, self._remote_acq.BEFORE_HARDWARE_HOOK)
         if post_hardware_hook_fn is not None:
             hook = self.bridge.construct_java_object('org.micromanager.remote.RemoteAcqHook', args=[self._remote_acq])
             self._start_hook(hook, post_hardware_hook_fn, self._event_queue, process=process)
             self._remote_acq.add_hook(hook, self._remote_acq.AFTER_HARDWARE_HOOK)
+        if post_camera_hook_fn is not None:
+            hook = self.bridge.construct_java_object('org.micromanager.remote.RemoteAcqHook', args=[self._remote_acq])
+            self._start_hook(hook, post_camera_hook_fn, self._event_queue, process=process)
+            self._remote_acq.add_hook(hook, self._remote_acq.AFTER_CAMERA_HOOK)
+
 
         self._remote_acq.start()
 
